@@ -1,13 +1,10 @@
 package Game::TileMap::Role::Checks;
-$Game::TileMap::Role::Checks::VERSION = '0.002';
+$Game::TileMap::Role::Checks::VERSION = '1.000';
 use v5.10;
 use strict;
 use warnings;
 
 use Moo::Role;
-use Mooish::AttributeBuilder -standard;
-
-use Game::TileMap::Legend;
 
 requires qw(
 	coordinates
@@ -20,7 +17,7 @@ sub check_within_map
 	return !!0 if $x < 0 || $y < 0;
 
 	my $obj = $self->coordinates->[$x][$y];
-	return $obj && $obj->type ne Game::TileMap::Legend::WALL_OBJECT;
+	return $obj && !$obj->is_wall;
 }
 
 sub check_can_be_accessed
@@ -30,7 +27,7 @@ sub check_can_be_accessed
 	return !!0 if $x < 0 || $y < 0;
 
 	my $obj = $self->coordinates->[$x][$y];
-	return $obj && $obj->type;
+	return $obj && !$obj->is_wall && !$obj->is_void;
 }
 
 1;
