@@ -1,13 +1,10 @@
 package Game::TileMap::Role::Helpers;
-$Game::TileMap::Role::Helpers::VERSION = '0.002';
+$Game::TileMap::Role::Helpers::VERSION = '1.000';
 use v5.10;
 use strict;
 use warnings;
 
 use Moo::Role;
-use Mooish::AttributeBuilder -standard;
-
-use Game::TileMap::Legend;
 
 requires qw(
 	legend
@@ -31,5 +28,12 @@ sub get_all_of_type
 	return grep { $_->type eq $obj } @all_of_class;
 }
 
+sub get_class_of_object
+{
+	my ($self, $obj) = @_;
+
+	return $self->legend->get_class_of_object(ref $obj ? $obj->type : $obj);
+}
+
 1;
 
