@@ -1,11 +1,12 @@
 package Game::TileMap::Tile;
-$Game::TileMap::Tile::VERSION = '0.002';
+$Game::TileMap::Tile::VERSION = '1.000';
 use v5.10;
 use strict;
 use warnings;
 
 use Moo;
 use Mooish::AttributeBuilder -standard;
+use Carp qw(croak);
 
 has param ['x', 'y'] => (
 
@@ -18,12 +19,37 @@ has param 'contents' => (
 	# isa => Any,
 );
 
+has field 'is_wall' => (
+	writer => -hidden,
+
+	# isa => Bool,
+);
+
+has field 'is_void' => (
+	writer => -hidden,
+
+	# isa => Bool,
+);
+
 has field 'type' => (
-	default => sub { shift->contents },
+	writer => -hidden,
 
 	# isa => Any,
 );
 
+sub BUILD
+{
+	my ($self, $args) = @_;
+
+	my $legend = $args->{legend};
+	croak "argument legend is required for Game::TileMap::Tile"
+		unless $legend;
+
+	$self->_set_type($self->contents);
+	$self->_set_is_void($legend->voids->{$self->type});
+	$self->_set_is_wall($legend->walls->{$self->type});
+}
+
 1;
 
 __END__
@@ -50,6 +76,14 @@ Vertical position of this tile on a map.
 
 Contents of the tile. By default, same as L</type>, but you can change it with L</set_contents>.
 
+=head3 is_wall
+
+Is this tile a wall?
+
+=head3 is_void
+
+Is this tile a void?
+
 =head3 type
 
 Type of the tile, as defined in the legend (as C<$object>)
@@ -60,6 +94,9 @@ Type of the tile, as defined in the legend (as C<$object>)
 
 Moose-flavored constructor. See L</Attributes> for a list of possible arguments.
 
+In addition, the constructor B<requires> the argument C<legend> - map legend, but
+it is only required during building of the object (not stored).
+
 =head3 set_contents
 
 Sets new L</contents> for this tile. Useful if you want to specify this tile
